/**
 * Copyright (C) 2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.objectweb.perseus.cache;

import org.objectweb.perseus.cache.api.CacheManager;
import org.objectweb.perseus.cache.api.CacheEntry;
import org.objectweb.perseus.cache.api.CacheAttributeController;
import org.objectweb.util.monolog.Monolog;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;

import java.util.HashMap;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class Application {
	public static void main(String[] args) throws Exception {
		Logger logger = Monolog.initialize().getLogger(Application.class.getName());
		CacheManager cm = null;
		CacheAttributeController cac = null;
		final int cacheSize = 50000;

		logger.log(BasicLevel.INFO, "CacheManager instance fetched, cache size=" + cacheSize + ".");
		cm = CacheManagerFactory.newCacheManager(cacheSize, CacheManagerFactory.LRU_POLICY);
		cac = (CacheAttributeController) cm;

		execute(cm, cac, logger);
	}
	
	public static void execute(CacheManager cm, CacheAttributeController cac, Logger logger) throws Exception {
		//bind entries to the cache
		HashMap o1 = new HashMap();
		o1.put("k1", new long[]{345234});
		logger.log(BasicLevel.INFO, "bind (\"id1\", " + o1 + ") to the cache");
		cm.bind("id1", o1);

		logger.log(BasicLevel.INFO, "bind (\"id2\", \"value1\") to the cache");
		cm.bind("id2", "value1");

		logger.log(BasicLevel.INFO, "Currently there are " + cac.getCurrentSize() + " entries");

		//check if the bound entries are available
		CacheEntry ce = cm.lookup("id1");
		if (ce == null) {
			throw new Exception("Error in the cache: no entry matching id1");
		}
		logger.log(BasicLevel.INFO, "lookup(\"id1\"): " +  cm.lookup("id1").getCeObject());
		if (ce.getCeObject() != o1) {
			throw new Exception(
				"Error in the cache: bad entry for the identifier id1: "
				+ ce.getCeObject());
		}

		ce = cm.lookup("id2");
		if (ce == null) {
			throw new Exception("Error in the cache: no entry matching id2");
		}
		logger.log(BasicLevel.INFO, "lookup(\"id2\"): " +  cm.lookup("id2").getCeObject());
		if (!"value1".equals(ce.getCeObject())) {
			throw new Exception(
				"Error in the cache: bad entry for the identifier id2: "
				+ ce.getCeObject());
		}
	}
}
