/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.cache.replacement.api;

import org.objectweb.perseus.cache.api.CacheException;
import org.objectweb.perseus.cache.api.FixableCacheEntry;
import org.objectweb.perseus.cache.api.UnbindManager;

/**
 * It defines  the  commun  methods associated  to  ReplacementManager
 * implementations. Every Cache must have a ReplacementManager.
 * The role of a ReplacementManager is to chose a set of objects to be
 * evicted  from the  cache, whenever cache  space is needed  (e.g. to
 *  store  a recently  arrived  object).  Typical implementations  for
 * ReplacementManagers include LRU, MRU, FIFO based.
 *
 * @author Luciano Garcia-Banuelos (Luciano.Garcia@imag.fr)
 */
public interface ReplacementManager extends UnbindManager {

	/**
	 *
	 * @param entry The cache entry that has been accessed.
	 *  @exception CacheException  Whenever an  internal error  occurs.
	 */
	void addForReplacement(FixableCacheEntry entry) throws CacheException;

	/**
	 * This method is called by the CacheManager in order to signal that an
	 * entry has been really evicted. In fact the eviction has been previously
	 * requested by the ReplacementManager, and now the GC garbaged an entry.
	 * @param oid is the evicted cache entry
	 */
	void removeForReplacement(Object oid);

	/**
	 * Called whenever an object has been accessed. Thus, this method,
	 * gives hints about recency/frequency of use. This hints are used
	 * within the replacement algorithm.
	 *
	 * @param entry The cache entry that has been accessed.
	 *  @exception CacheException  Whenever an  internal error  occurs.
	 **/
	void adjustForReplacement(FixableCacheEntry entry) throws CacheException;


	/**
	 * It forces the replacement manager to free CacheEntry instances from the
	 * cache.
	 * @param capacity is the quantity of space required by the cache.
	 */
	int forceFree(int capacity) throws CacheException;
}
